/**
 * An interface for a JavaScript object that
 * acts a dictionary. The keys are strings.
 */
export interface IStringDictionary<V> {
    [name: string]: V;
}
/**
 * Looks up and returns a property that is owned
 * by the provided map object.
 * @param what The key.
 * @param from A native JavaScript object that stores items.
 * @param alternate A default value this is return in case an item with
 *     the key isn"t found.
 */
export declare function lookup<T>(from: IStringDictionary<T>, what: string, alternate?: T): T | null;
/**
 * Returns {{true}} iff the provided object contains a property
 * with the given name.
 */
export declare function contains<T>(from: IStringDictionary<T>, what: string): boolean;
/**
 * Iterates over each entry in the provided set. The iterator allows
 * to remove elements and will stop when the callback returns {{false}}.
 */
export declare function forEach<T>(from: IStringDictionary<T>, callback: (entry: {
    key: string;
    value: T;
}, remove: Function) => any): void;
